# Hi! My name is Viet Anh. I'm a software developer from Vietnam.

This is my personal utility library for software development. It contains
a lot of useful stuff that I use in my projects. It is not intended to be
a general purpose library, but it may be useful for you too.

- **My blog:** [https://aicurious.io](https://aicurious.io/).
- **My LinkedIn:** [https://www.linkedin.com/in/vietanhdev/](https://www.linkedin.com/in/vietanhdev/).
